Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlex Zolotarev <deathbaba@gmail.com>2011-05-03 02:47:26 +0400
committerAlex Zolotarev <alex@maps.me>2015-09-23 01:16:55 +0300
commitf91561f65cf2dd54cfafd636c13d0aac567c935c (patch)
tree0643f0304e2fbf1a41f721170b614501205c6f4b /platform
parent693ea0c525dc884278e474c1c8b7ec1138bf13e0 (diff)
Unique client ids are only set in HTTP requests to mapswithme.com servers
- Changed dev server address to strong mapswithme.com subdomain
Diffstat (limited to 'platform')
-rw-r--r--platform/qt_download.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/platform/qt_download.cpp b/platform/qt_download.cpp
index dce170210c..658b650711 100644
--- a/platform/qt_download.cpp
+++ b/platform/qt_download.cpp
@@ -147,8 +147,9 @@ QtDownload::~QtDownload()
void QtDownload::StartRequest()
{
QNetworkRequest httpRequest(m_currentUrl);
- // set user-agent with unique client id
- httpRequest.setRawHeader("User-Agent", UserAgent().toAscii());
+ // set user-agent with unique client id only for mapswithme requests
+ if (m_params.m_url.find("mapswithme.com") != string::npos)
+ httpRequest.setRawHeader("User-Agent", UserAgent().toAscii());
if (m_file.isOpen())
{
qint64 const fileSize = m_file.size();